@@ -1908,6 +1908,262 @@ impl Data for FR_FR {
         "Zola",
     ];
 
+    const NAME_TITLE: &'static [&'static str] = &["Mme", "M."];
+
+    const ADDRESS_CITY_TPL: &'static str = "{CityName}";
+
+    const ADDRESS_STREET_SUFFIX: &'static [&'static str] = &[
+        "Allée", "Avenue", "Rue", "Cours", "Venelle", "Impasse", "Place",
+    ];
+
+    const ADDRESS_STREET_TPL: &'static str = "{StreetSuffix} {StreetName}";
+
+    // Country list in french:
+    // https://sql.sh/514-liste-pays-csv-xml
+    const ADDRESS_COUNTRY: &'static [&'static str] = &[
+        "Afghanistan",
+        "Albanie",
+        "Antarctique",
+        "Algérie",
+        "Samoa Américaines",
+        "Andorre",
+        "Angola",
+        "Antigua-et-Barbuda",
+        "Azerbaïdjan",
+        "Argentine",
+        "Australie",
+        "Autriche",
+        "Bahamas",
+        "Bahreïn",
+        "Bangladesh",
+        "Arménie",
+        "Barbade",
+        "Belgique",
+        "Bermudes",
+        "Bhoutan",
+        "Bolivie",
+        "Bosnie-Herzégovine",
+        "Botswana",
+        "Île Bouvet",
+        "Brésil",
+        "Belize",
+        "Territoire Britannique de l'Océan Indien",
+        "Îles Salomon",
+        "Îles Vierges Britanniques",
+        "Brunéi Darussalam",
+        "Bulgarie",
+        "Myanmar",
+        "Burundi",
+        "Bélarus",
+        "Cambodge",
+        "Cameroun",
+        "Canada",
+        "Cap-vert",
+        "Îles Caïmanes",
+        "République Centrafricaine",
+        "Sri Lanka",
+        "Tchad",
+        "Chili",
+        "Chine",
+        "Taïwan",
+        "Île Christmas",
+        "Îles Cocos (Keeling)",
+        "Colombie",
+        "Comores",
+        "Mayotte",
+        "République du Congo",
+        "République Démocratique du Congo",
+        "Îles Cook",
+        "Costa Rica",
+        "Croatie",
+        "Cuba",
+        "Chypre",
+        "République Tchèque",
+        "Bénin",
+        "Danemark",
+        "Dominique",
+        "République Dominicaine",
+        "Équateur",
+        "El Salvador",
+        "Guinée Équatoriale",
+        "Éthiopie",
+        "Érythrée",
+        "Estonie",
+        "Îles Féroé",
+        "Îles (malvinas) Falkland",
+        "Géorgie du Sud et les Îles Sandwich du Sud",
+        "Fidji",
+        "Finlande",
+        "Îles Åland",
+        "France",
+        "Guyane Française",
+        "Polynésie Française",
+        "Terres Australes Françaises",
+        "Djibouti",
+        "Gabon",
+        "Géorgie",
+        "Gambie",
+        "Territoire Palestinien Occupé",
+        "Allemagne",
+        "Ghana",
+        "Gibraltar",
+        "Kiribati",
+        "Grèce",
+        "Groenland",
+        "Grenade",
+        "Guadeloupe",
+        "Guam",
+        "Guatemala",
+        "Guinée",
+        "Guyana",
+        "Haïti",
+        "Îles Heard et Mcdonald",
+        "Saint-Siège (état de la Cité du Vatican)",
+        "Honduras",
+        "Hong-Kong",
+        "Hongrie",
+        "Islande",
+        "Inde",
+        "Indonésie",
+        "République Islamique d'Iran",
+        "Iraq",
+        "Irlande",
+        "Israël",
+        "Italie",
+        "Côte d'Ivoire",
+        "Jamaïque",
+        "Japon",
+        "Kazakhstan",
+        "Jordanie",
+        "Kenya",
+        "République Populaire Démocratique de Corée",
+        "République de Corée",
+        "Koweït",
+        "Kirghizistan",
+        "République Démocratique Populaire Lao",
+        "Liban",
+        "Lesotho",
+        "Lettonie",
+        "Libéria",
+        "Jamahiriya Arabe Libyenne",
+        "Liechtenstein",
+        "Lituanie",
+        "Luxembourg",
+        "Macao",
+        "Madagascar",
+        "Malawi",
+        "Malaisie",
+        "Maldives",
+        "Mali",
+        "Malte",
+        "Martinique",
+        "Mauritanie",
+        "Maurice",
+        "Mexique",
+        "Monaco",
+        "Mongolie",
+        "République de Moldova",
+        "Montserrat",
+        "Maroc",
+        "Mozambique",
+        "Oman",
+        "Namibie",
+        "Nauru",
+        "Népal",
+        "Pays-Bas",
+        "Antilles Néerlandaises",
+        "Aruba",
+        "Nouvelle-Calédonie",
+        "Vanuatu",
+        "Nouvelle-Zélande",
+        "Nicaragua",
+        "Niger",
+        "Nigéria",
+        "Niué",
+        "Île Norfolk",
+        "Norvège",
+        "Îles Mariannes du Nord",
+        "Îles Mineures Éloignées des États-Unis",
+        "États Fédérés de Micronésie",
+        "Îles Marshall",
+        "Palaos",
+        "Pakistan",
+        "Panama",
+        "Papouasie-Nouvelle-Guinée",
+        "Paraguay",
+        "Pérou",
+        "Philippines",
+        "Pitcairn",
+        "Pologne",
+        "Portugal",
+        "Guinée-Bissau",
+        "Timor-Leste",
+        "Porto Rico",
+        "Qatar",
+        "Réunion",
+        "Roumanie",
+        "Fédération de Russie",
+        "Rwanda",
+        "Sainte-Hélène",
+        "Saint-Kitts-et-Nevis",
+        "Anguilla",
+        "Sainte-Lucie",
+        "Saint-Pierre-et-Miquelon",
+        "Saint-Vincent-et-les Grenadines",
+        "Saint-Marin",
+        "Sao Tomé-et-Principe",
+        "Arabie Saoudite",
+        "Sénégal",
+        "Seychelles",
+        "Sierra Leone",
+        "Singapour",
+        "Slovaquie",
+        "Viet Nam",
+        "Slovénie",
+        "Somalie",
+        "Afrique du Sud",
+        "Zimbabwe",
+        "Espagne",
+        "Sahara Occidental",
+        "Soudan",
+        "Suriname",
+        "Svalbard etÎle Jan Mayen",
+        "Swaziland",
+        "Suède",
+        "Suisse",
+        "République Arabe Syrienne",
+        "Tadjikistan",
+        "Thaïlande",
+        "Togo",
+        "Tokelau",
+        "Tonga",
+        "Trinité-et-Tobago",
+        "Émirats Arabes Unis",
+        "Tunisie",
+        "Turquie",
+        "Turkménistan",
+        "Îles Turks et Caïques",
+        "Tuvalu",
+        "Ouganda",
+        "Ukraine",
+        "L'ex-République Yougoslave de Macédoine",
+        "Égypte",
+        "Royaume-Uni",
+        "Île de Man",
+        "République-Unie de Tanzanie",
+        "États-Unis",
+        "Îles Vierges des États-Unis",
+        "Burkina Faso",
+        "Uruguay",
+        "Ouzbékistan",
+        "Venezuela",
+        "Wallis et Futuna",
+        "Samoa",
+        "Yémen",
+        "Serbie-et-Monténégro",
+        "Zambie",
+    ];
+
     const INTERNET_FREE_EMAIL_PROVIDER: &'static [&'static str] = &[
         "free.fr",
         "sfr.fr",
@@ -1927,7 +2183,7 @@ impl Data for FR_FR {
         "09 ## ## ## ##",
     ];
     const PHONE_CELL_NUMBER_FORMATS: &'static [&'static str] =
-        &["06 ## ## ## ##", "07 ## ## ## ##"];
+        &["06 ## ## ## ##", "07 ## ## ## ##", "09 ## ## ## ##"];
 }
 
 impl CityNameGenFn for FR_FR {}
