@@ -1,15 +1,15 @@
 //! Unlinking packages from an environment.
 
-use fs_err::tokio as tokio_fs;
 use std::{
     collections::HashSet,
     ffi::OsString,
     io::ErrorKind,
     path::{Path, PathBuf},
 };
-use uuid::Uuid;
 
-use rattler_conda_types::PrefixRecord;
+use fs_err::tokio as tokio_fs;
+use rattler_conda_types::{prefix::Prefix, prefix_record::PrefixRecord};
+use uuid::Uuid;
 
 /// Error that can occur while unlinking a package.
 #[derive(Debug, thiserror::Error)]
@@ -154,20 +154,12 @@ pub async fn empty_trash(target_prefix: &Path) -> Result<(), UnlinkError> {
     Ok(())
 }
 
-async fn move_to_trash(target_prefix: &Path, path: &Path) -> Result<(), UnlinkError> {
-    let mut trash_dest = target_prefix.join(".trash");
-    match tokio::fs::try_exists(&trash_dest).await {
-        Ok(true) => {}
-        Ok(false) => tokio_fs::create_dir(&trash_dest).await.map_err(|e| {
-            UnlinkError::FailedToCreateDirectory(trash_dest.to_string_lossy().to_string(), e)
-        })?,
-        Err(e) => {
-            return Err(UnlinkError::FailedToTestExistence(
-                trash_dest.to_string_lossy().to_string(),
-                e,
-            ))
-        }
-    }
+async fn move_to_trash(target_prefix: &Prefix, path: &Path) -> Result<(), UnlinkError> {
+    let mut trash_dest = target_prefix.get_trash_dir();
+    tokio_fs::create_dir_all(&trash_dest).await.map_err(|e| {
+        UnlinkError::FailedToCreateDirectory(trash_dest.to_string_lossy().to_string(), e)
+    })?;
+
     let mut new_filename = OsString::new();
     if let Some(file_name) = path.file_name() {
         new_filename.push(file_name);
@@ -187,12 +179,12 @@ async fn move_to_trash(target_prefix: &Path, path: &Path) -> Result<(), UnlinkEr
 
 /// Completely remove the specified package from the environment.
 pub async fn unlink_package(
-    target_prefix: &Path,
+    target_prefix: &Prefix,
     prefix_record: &PrefixRecord,
 ) -> Result<(), UnlinkError> {
     // Remove all entries
     for paths in prefix_record.paths_data.paths.iter() {
-        let p = target_prefix.join(&paths.relative_path);
+        let p = target_prefix.path().join(&paths.relative_path);
         match tokio_fs::remove_file(&p).await {
             Ok(_) => {}
             Err(e) => match e.kind() {
@@ -227,67 +219,26 @@ mod tests {
         fs::{self, File},
         io::Write,
         path::Path,
-        str::FromStr,
     };
 
-    use rattler_conda_types::{Platform, PrefixRecord, RepoDataRecord, Version};
-    use url::Url;
+    use rattler_conda_types::{prefix::Prefix, Platform, RepoDataRecord};
 
-    use crate::{
-        get_repodata_record,
-        install::{
-            empty_trash, link_package, unlink_package, InstallDriver, InstallOptions, PythonInfo,
-            Transaction,
-        },
-    };
-
-    async fn link_ruff(target_prefix: &Path, package_url: Url, sha256_hash: &str) -> PrefixRecord {
-        let package_path = tools::download_and_cache_file_async(package_url, sha256_hash)
-            .await
-            .unwrap();
-
-        let package_dir = tempfile::TempDir::new().unwrap();
-
-        // Create package cache
-        rattler_package_streaming::fs::extract(&package_path, package_dir.path()).unwrap();
-
-        let py_info =
-            PythonInfo::from_version(&Version::from_str("3.10").unwrap(), None, Platform::Linux64)
-                .unwrap();
-        let install_options = InstallOptions {
-            python_info: Some(py_info),
-            ..InstallOptions::default()
-        };
-
-        let install_driver = InstallDriver::default();
-        // Link the package
-        let paths = link_package(
-            package_dir.path(),
-            target_prefix,
-            &install_driver,
-            install_options,
-        )
-        .await
-        .unwrap();
-
-        let repodata_record = get_repodata_record(&package_path);
-        // Construct a PrefixRecord for the package
-
-        PrefixRecord::from_repodata_record(repodata_record, None, None, paths, None, None)
-    }
+    use crate::install::test_utils::download_and_get_prefix_record;
+    use crate::install::{empty_trash, unlink_package, InstallDriver, Transaction};
 
     #[tokio::test]
     async fn test_unlink_package() {
         let environment_dir = tempfile::TempDir::new().unwrap();
-        let prefix_record = link_ruff(
-            environment_dir.path(),
+        let prefix = Prefix::create(environment_dir.path()).unwrap();
+        let prefix_record = download_and_get_prefix_record(
+            &prefix,
             "https://conda.anaconda.org/conda-forge/win-64/ruff-0.0.171-py310h298983d_0.conda"
                 .parse()
                 .unwrap(),
             "25c755b97189ee066576b4ae3999d5e7ff4406d236b984742194e63941838dcd",
         )
         .await;
-        let conda_meta_path = environment_dir.path().join("conda-meta");
+        let conda_meta_path = prefix.path().join("conda-meta");
         std::fs::create_dir_all(&conda_meta_path).unwrap();
 
         // Write the conda-meta information
@@ -295,9 +246,7 @@ mod tests {
         prefix_record.write_to_path(&pkg_meta_path, true).unwrap();
 
         // Unlink the package
-        unlink_package(environment_dir.path(), &prefix_record)
-            .await
-            .unwrap();
+        unlink_package(&prefix, &prefix_record).await.unwrap();
 
         // Check if the conda-meta file is gone
         assert!(!pkg_meta_path.exists());
@@ -308,6 +257,7 @@ mod tests {
         let transaction = Transaction::from_current_and_desired(
             vec![prefix_record.clone()],
             Vec::<RepoDataRecord>::new().into_iter(),
+            None,
             Platform::current(),
         )
         .unwrap();
@@ -328,8 +278,9 @@ mod tests {
     #[tokio::test]
     async fn test_unlink_package_python_noarch() {
         let target_prefix = tempfile::TempDir::new().unwrap();
-        let prefix_record = link_ruff(
-            target_prefix.path(),
+        let target_prefix = Prefix::create(target_prefix.path()).unwrap();
+        let prefix_record = download_and_get_prefix_record(
+            &target_prefix,
             "https://conda.anaconda.org/conda-forge/noarch/pytweening-1.0.4-pyhd8ed1ab_0.tar.bz2"
                 .parse()
                 .unwrap(),
@@ -359,7 +310,7 @@ mod tests {
         file.sync_all().unwrap();
 
         // Unlink the package
-        unlink_package(target_prefix.path(), &prefix_record)
+        unlink_package(&target_prefix, &prefix_record)
             .await
             .unwrap();
 
@@ -370,6 +321,7 @@ mod tests {
         let transaction = Transaction::from_current_and_desired(
             vec![prefix_record.clone()],
             Vec::<RepoDataRecord>::new().into_iter(),
+            None,
             Platform::current(),
         )
         .unwrap();
@@ -404,13 +356,21 @@ mod tests {
     #[cfg(windows)]
     #[tokio::test]
     async fn test_unlink_package_in_use() {
+        use crate::get_repodata_record;
+        use crate::install::link_package;
+        use crate::install::InstallOptions;
+        use rattler_conda_types::PrefixRecord;
+        use std::{
+            env::{join_paths, split_paths, var_os},
+            io::{BufRead, BufReader},
+            process::{Command, Stdio},
+        };
+
         use itertools::chain;
-        use std::env::{join_paths, split_paths, var_os};
-        use std::io::{BufRead, BufReader};
-        use std::process::{Command, Stdio};
 
         let environment_dir = tempfile::TempDir::new().unwrap();
         let target_prefix = environment_dir.path();
+        let prefix = Prefix::create(target_prefix).unwrap();
         let trash_dir = target_prefix.join(".trash");
         let files = [
             ("https://conda.anaconda.org/conda-forge/win-64/bat-0.24.0-ha073cba_1.conda", "65a125b7a6e7fd7e5d4588ee537b5db2c984ed71e4832f7041f691c2cfd73504"),
@@ -436,7 +396,7 @@ mod tests {
             // Link the package
             let paths = link_package(
                 package_dir.path(),
-                target_prefix,
+                &prefix,
                 &install_driver,
                 InstallOptions::default(),
             )
@@ -485,13 +445,13 @@ mod tests {
         let mut stdout = BufReader::new(child.stdout.take().expect("failed to open stdout"));
         // Ensure program has started by waiting for it to repeat back to us.
         let mut line = String::new();
-        stdin.write("abc\n".as_bytes()).unwrap();
+        stdin.write_all(b"abc\n").unwrap();
         stdout.read_line(&mut line).unwrap();
 
         // Unlink the package
         assert!(!trash_dir.exists());
         let prefix_record = prefix_records.first().unwrap();
-        unlink_package(target_prefix, prefix_record).await.unwrap();
+        unlink_package(&prefix, prefix_record).await.unwrap();
         // Check if the conda-meta file is gone
         assert!(!conda_meta_path.join(prefix_record.file_name()).exists());
         assert!(trash_dir.exists());
