@@ -23,7 +23,6 @@ use rattler_digest::Sha256Hash;
 use rattler_networking::retry_policies::{DoNotRetryPolicy, RetryDecision, RetryPolicy};
 use rattler_package_streaming::{DownloadReporter, ExtractError};
 pub use reporter::CacheReporter;
-use reqwest::StatusCode;
 use simple_spawn_blocking::Cancelled;
 use tracing::instrument;
 use url::Url;
@@ -44,6 +43,7 @@ mod reporter;
 #[derive(Clone)]
 pub struct PackageCache {
     inner: Arc<PackageCacheInner>,
+    cache_origin: bool,
 }
 
 #[derive(Default)]
@@ -58,6 +58,7 @@ pub struct BucketKey {
     name: String,
     version: String,
     build_string: String,
+    origin_hash: Option<String>,
 }
 
 impl From<CacheKey> for BucketKey {
@@ -66,6 +67,7 @@ impl From<CacheKey> for BucketKey {
             name: key.name,
             version: key.version,
             build_string: key.build_string,
+            origin_hash: key.origin_hash,
         }
     }
 }
@@ -107,6 +109,16 @@ impl PackageCache {
                 path: path.into(),
                 packages: DashMap::default(),
             }),
+            cache_origin: false,
+        }
+    }
+
+    /// Adds the origin (url or path) to the cache key to avoid unwanted cache hits of packages
+    /// with packages with similar properties.
+    pub fn with_cached_origin(self) -> Self {
+        Self {
+            cache_origin: true,
+            ..self
         }
     }
 
@@ -131,7 +143,7 @@ impl PackageCache {
         Fut: Future<Output = Result<(), E>> + Send + 'static,
         E: std::error::Error + Send + Sync + 'static,
     {
-        let cache_key = pkg.into();
+        let cache_key: CacheKey = pkg.into();
         let cache_path = self.inner.path.join(cache_key.to_string());
         let cache_entry = self
             .inner
@@ -189,13 +201,18 @@ impl PackageCache {
         path: &Path,
         reporter: Option<Arc<dyn CacheReporter>>,
     ) -> Result<CacheLock, PackageCacheError> {
-        let path = path.to_path_buf();
+        let path_buf = path.to_path_buf();
+        let mut cache_key: CacheKey = ArchiveIdentifier::try_from_path(&path_buf).unwrap().into();
+        if self.cache_origin {
+            cache_key = cache_key.with_path(path);
+        }
+
         self.get_or_fetch(
-            ArchiveIdentifier::try_from_path(&path).unwrap(),
+            cache_key,
             move |destination| {
-                let path = path.clone();
+                let path_buf = path_buf.clone();
                 async move {
-                    rattler_package_streaming::tokio::fs::extract(&path, &destination)
+                    rattler_package_streaming::tokio::fs::extract(&path_buf, &destination)
                         .await
                         .map(|_| ())
                 }
@@ -210,6 +227,12 @@ impl PackageCache {
     /// This is a convenience wrapper around `get_or_fetch` which fetches the
     /// package from the given URL if the package could not be found in the
     /// cache.
+    ///
+    /// This function assumes that the `client` is already configured with a
+    /// retry middleware that will retry any request that fails. This function
+    /// uses the passed in `retry_policy` if, after the request has been sent
+    /// and the response is successful, streaming of the package data fails
+    /// and the whole request must be retried.
     #[instrument(skip_all, fields(url=%url))]
     pub async fn get_or_fetch_from_url_with_retry(
         &self,
@@ -221,7 +244,10 @@ impl PackageCache {
     ) -> Result<CacheLock, PackageCacheError> {
         let request_start = SystemTime::now();
         // Convert into cache key
-        let cache_key = pkg.into();
+        let mut cache_key = pkg.into();
+        if self.cache_origin {
+            cache_key = cache_key.with_url(url.clone());
+        }
         // Sha256 of the expected package
         let sha256 = cache_key.sha256();
         let download_reporter = reporter.clone();
@@ -253,17 +279,12 @@ impl PackageCache {
                     // Extract any potential error
                     let Err(err) = result else { return Ok(()); };
 
-                    // Only retry on certain errors.
-                    if !matches!(
-                    &err,
-                    ExtractError::IoError(_) | ExtractError::CouldNotCreateDestination(_)
-                ) && !matches!(&err, ExtractError::ReqwestError(err) if
-                    err.is_timeout() ||
-                    err.is_connect() ||
-                    err
-                        .status()
-                        .map_or(false, |status| status.is_server_error() || status == StatusCode::TOO_MANY_REQUESTS || status == StatusCode::REQUEST_TIMEOUT)
-                ) {
+                    // Only retry on io errors. We assume that the user has
+                    // middleware installed that handles connection retries.
+
+                    if !matches!(&err,
+                        ExtractError::IoError(_) | ExtractError::CouldNotCreateDestination(_)
+                    ) {
                         return Err(err);
                     }
 
@@ -349,9 +370,7 @@ where
             let reporter = reporter.as_deref().map(|r| (r, r.on_validate_start()));
 
             // If we know the revision is already valid we can return immediately.
-            if validated_revision.map_or(false, |validated_revision| {
-                validated_revision == cache_revision
-            }) {
+            if validated_revision == Some(cache_revision) {
                 if let Some((reporter, index)) = reporter {
                     reporter.on_validate_complete(index);
                 }
@@ -500,16 +519,21 @@ mod test {
     use bytes::Bytes;
     use futures::stream;
     use rattler_conda_types::package::{ArchiveIdentifier, PackageFile, PathsJson};
-    use rattler_digest::{parse_digest_from_hex, Sha256};
+    use rattler_digest::{compute_bytes_digest, parse_digest_from_hex, Sha256};
     use rattler_networking::retry_policies::{DoNotRetryPolicy, ExponentialBackoffBuilder};
+    use reqwest::Client;
+    use reqwest_middleware::ClientBuilder;
+    use reqwest_retry::RetryTransientMiddleware;
     use tempfile::tempdir;
     use tokio::sync::Mutex;
     use tokio_stream::StreamExt;
     use url::Url;
 
     use super::PackageCache;
-    use crate::validation::ValidationMode;
-    use crate::{package_cache::CacheKey, validation::validate_package_directory};
+    use crate::{
+        package_cache::CacheKey,
+        validation::{validate_package_directory, ValidationMode},
+    };
 
     fn get_test_data_dir() -> PathBuf {
         Path::new(env!("CARGO_MANIFEST_DIR")).join("../../test-data")
@@ -630,23 +654,18 @@ mod test {
         FailAfterBytes(usize),
     }
 
-    async fn redirect_to_anaconda(
+    async fn redirect_to_prefix(
         axum::extract::Path((channel, subdir, file)): axum::extract::Path<(String, String, String)>,
     ) -> Redirect {
-        Redirect::permanent(&format!(
-            "https://conda.anaconda.org/{channel}/{subdir}/{file}"
-        ))
+        Redirect::permanent(&format!("https://prefix.dev/{channel}/{subdir}/{file}"))
     }
 
     async fn test_flaky_package_cache(archive_name: &str, middleware: Middleware) {
-        let static_dir = get_test_data_dir();
-        println!("Serving files from {}", static_dir.display());
-
         // Construct a service that serves raw files from the test directory
         // build our application with a route
         let router = Router::new()
             // `GET /` goes to `root`
-            .route("/:channel/:subdir/:file", get(redirect_to_anaconda));
+            .route("/{channel}/{subdir}/{file}", get(redirect_to_prefix));
 
         // Construct a router that returns data from the static dir but fails the first
         // try.
@@ -679,12 +698,14 @@ mod test {
 
         let server_url = Url::parse(&format!("http://localhost:{}", addr.port())).unwrap();
 
+        let client = ClientBuilder::new(Client::default()).build();
+
         // Do the first request without
         let result = cache
             .get_or_fetch_from_url_with_retry(
                 ArchiveIdentifier::try_from_filename(archive_name).unwrap(),
                 server_url.join(archive_name).unwrap(),
-                reqwest::Client::default().into(),
+                client.clone(),
                 DoNotRetryPolicy,
                 None,
             )
@@ -697,13 +718,18 @@ mod test {
             assert_eq!(*request_count_lock, 1, "Expected there to be 1 request");
         }
 
+        let retry_policy = ExponentialBackoffBuilder::default().build_with_max_retries(3);
+        let client = ClientBuilder::from_client(client)
+            .with(RetryTransientMiddleware::new_with_policy(retry_policy))
+            .build();
+
         // The second one should fail after the 2nd try
         let result = cache
             .get_or_fetch_from_url_with_retry(
                 ArchiveIdentifier::try_from_filename(archive_name).unwrap(),
                 server_url.join(archive_name).unwrap(),
-                reqwest::Client::default().into(),
-                ExponentialBackoffBuilder::default().build_with_max_retries(3),
+                client,
+                retry_policy,
                 None,
             )
             .await;
@@ -770,6 +796,38 @@ mod test {
         assert_eq!(cache_c_lock.revision(), 2);
     }
 
+    fn get_file_name_from_path(path: &Path) -> &str {
+        path.file_name().unwrap().to_str().unwrap()
+    }
+
+    #[tokio::test]
+    async fn test_origin_hash_from_path() {
+        let packages_dir = tempdir().unwrap();
+        let package_cache_with_origin_hash = PackageCache::new(packages_dir.path());
+        let package_cache_without_origin_hash =
+            PackageCache::new(packages_dir.path()).with_cached_origin();
+
+        let package_path = get_test_data_dir().join("clobber/clobber-python-0.1.0-cpython.conda");
+
+        let cache_lock_with_origin_hash = package_cache_with_origin_hash
+            .get_or_fetch_from_path(&package_path, None)
+            .await
+            .unwrap();
+
+        let file_name = get_file_name_from_path(cache_lock_with_origin_hash.path());
+        assert_eq!(file_name, "clobber-python-0.1.0-cpython");
+
+        let cache_lock_without_origin_hash = package_cache_without_origin_hash
+            .get_or_fetch_from_path(&package_path, None)
+            .await
+            .unwrap();
+
+        let file_name = get_file_name_from_path(cache_lock_without_origin_hash.path());
+        let path_hash = compute_bytes_digest::<Sha256>(package_path.to_string_lossy().as_bytes());
+        let expected_file_name = format!("clobber-python-0.1.0-cpython-{:x}", path_hash);
+        assert_eq!(file_name, expected_file_name);
+    }
+
     #[tokio::test]
     // Test if packages with different sha's are replaced even though they share the
     // same BucketKey.
