@@ -476,6 +476,12 @@ pub fn ExitWindowsEx(
 	bool_to_sysresult(unsafe { ffi::ExitWindowsEx(flags.raw(), reason.raw()) })
 }
 
+/// [`FlashWindowEx`](https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-flashwindowex)
+/// function.
+pub fn FlashWindowEx(fwi: &FLASHWINFO) -> u32 {
+	unsafe { ffi::FlashWindowEx(fwi as *const _ as _) as _ }
+}
+
 /// [`GetAsyncKeyState`](https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getasynckeystate)
 /// function.
 ///
@@ -525,7 +531,7 @@ pub fn GetCaretPos() -> SysResult<POINT> {
 /// * [`SetClipboardData`](crate::SetClipboardData)
 #[must_use]
 pub unsafe fn GetClipboardData(format: co::CF) -> SysResult<*mut u8> {
-	ptr_to_sysresult(ffi::GetClipboardData(format.raw()))
+	ptr_to_sysresult(ffi::GetClipboardData(format.raw() as _))
 		.map(|hmem| hmem as *mut _ as _)
 }
 
@@ -610,7 +616,22 @@ pub fn GetGUIThreadInfo(thread_id: u32) -> SysResult<GUITHREADINFO> {
 #[must_use]
 pub fn GetLastInputInfo() -> SysResult<LASTINPUTINFO> {
 	let mut lii = LASTINPUTINFO::default();
-	bool_to_sysresult(unsafe {ffi::GetLastInputInfo(&mut lii as *mut _ as _)}).map(|_|lii)
+	bool_to_sysresult(unsafe { ffi::GetLastInputInfo(&mut lii as *mut _ as _) })
+		.map(|_|lii)
+}
+
+/// [`GetPhysicalCursorPos`](https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getphysicalcursorpos)
+/// function.
+///
+/// # Related functions
+///
+/// * [`SetPhysicalCursorPos`](crate::SetPhysicalCursorPos)
+#[must_use]
+pub fn GetPhysicalCursorPos() -> SysResult<POINT> {
+	let mut pt = POINT::default();
+	bool_to_sysresult(
+		unsafe { ffi::GetPhysicalCursorPos(&mut pt as *mut _ as _) },
+	).map(|_| pt)
 }
 
 /// [`GetMessage`](https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getmessagew)
@@ -649,6 +670,21 @@ pub fn GetMessagePos() -> POINT {
 	POINT::from(unsafe { ffi::GetMessagePos() })
 }
 
+/// [`GetProcessDefaultLayout`](https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getprocessdefaultlayout)
+/// function.
+///
+/// # Related functions
+///
+/// * [`SetProcessDefaultLayout`](crate::SetProcessDefaultLayout)
+#[must_use]
+pub fn GetProcessDefaultLayout() -> SysResult<co::LAYOUT> {
+	let mut dl = u32::default();
+	unsafe {
+		bool_to_sysresult(ffi::GetProcessDefaultLayout(&mut dl as _))
+			.map(|_| co::LAYOUT::from_raw(dl))
+	}
+}
+
 /// [`GetQueueStatus`](https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getqueuestatus)
 /// function.
 #[must_use]
@@ -658,6 +694,10 @@ pub fn GetQueueStatus(flags: co::QS) -> u32 {
 
 /// [`GetSysColor`](https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-getsyscolor)
 /// function.
+///
+/// # Related functions
+///
+/// * [`SetSysColors`](crate::SetSysColors)
 #[must_use]
 pub fn GetSysColor(index: co::COLOR) -> COLORREF {
 	unsafe { COLORREF::from_raw(ffi::GetSysColor(index.raw())) }
@@ -770,6 +810,12 @@ pub fn LockSetForegroundWindow(lock_code: co::LSFW) -> SysResult<()> {
 	bool_to_sysresult(unsafe { ffi::LockSetForegroundWindow(lock_code.raw()) })
 }
 
+/// [`MessageBeep`](https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-messagebeep)
+/// function.
+pub fn MessageBeep(sound_type: co::MBP) -> SysResult<()> {
+	bool_to_sysresult(unsafe { ffi::MessageBeep(sound_type.raw()) })
+}
+
 /// [`OffsetRect`](https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-offsetrect)
 /// function.
 #[must_use]
@@ -945,7 +991,7 @@ pub unsafe fn SetClipboardData(
 	hmem: *mut u8,
 ) -> SysResult<*mut u8>
 {
-	ptr_to_sysresult(ffi::SetClipboardData(format.raw(), hmem as _))
+	ptr_to_sysresult(ffi::SetClipboardData(format.raw() as _, hmem as _))
 		.map(|hmem| hmem as *mut _ as _)
 }
 
@@ -962,17 +1008,63 @@ pub fn SetDoubleClickTime(ms: u32) -> SysResult<()> {
 	bool_to_sysresult(unsafe { ffi::SetDoubleClickTime(ms) })
 }
 
+/// [`SetPhysicalCursorPos`](https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-setphysicalcursorpos)
+/// function.
+///
+/// # Related functions
+///
+/// * [`GetPhysicalCursorPos`](crate::GetPhysicalCursorPos)
+pub fn SetPhysicalCursorPos(x: i32, y: i32) -> SysResult<()> {
+	bool_to_sysresult(unsafe { ffi::SetPhysicalCursorPos(x, y) })
+}
+
+/// [`SetProcessDefaultLayout`](https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-setprocessdefaultlayout)
+/// function.
+///
+/// # Related functions
+///
+/// * [`GetProcessDefaultLayout`](crate::GetProcessDefaultLayout)
+pub fn SetProcessDefaultLayout(layout: co::LAYOUT) -> SysResult<()> {
+	bool_to_sysresult(unsafe { ffi::SetProcessDefaultLayout(layout.raw()) })
+}
+
 /// [`SetProcessDPIAware`](https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-setprocessdpiaware)
 /// function.
 pub fn SetProcessDPIAware() -> SysResult<()> {
 	bool_to_sysresult(unsafe { ffi::SetProcessDPIAware() })
 }
 
+/// [`SetSysColors`](https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-setsyscolors)
+/// function.
+///
+/// # Related functions
+///
+/// * [`GetSysColor`](crate::GetSysColor)
+pub fn SetSysColors(
+	elements_and_colors: &[(co::COLOR, COLORREF)],
+) -> SysResult<()>
+{
+	let (elems, colors): (Vec<_>, Vec<_>) = elements_and_colors.iter()
+		.map(|ec| (ec.0.raw(), ec.1.raw()))
+		.unzip();
+
+	bool_to_sysresult(
+		unsafe {
+			ffi::SetSysColors(
+				elements_and_colors.len() as _,
+				elems.as_ptr(),
+				colors.as_ptr(),
+			)
+		},
+	)
+}
+
 /// [`SetThreadDpiHostingBehavior`](https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-setthreaddpihostingbehavior)
 /// function.
 pub fn SetThreadDpiHostingBehavior(
 	value: co::DPI_HOSTING_BEHAVIOR,
-) -> co::DPI_HOSTING_BEHAVIOR {
+) -> co::DPI_HOSTING_BEHAVIOR
+{
 	unsafe {
 		co::DPI_HOSTING_BEHAVIOR::from_raw(
 			ffi::SetThreadDpiHostingBehavior(value.raw()),
